Summary:        High-performance, full-featured text search engine
Name:           lucene3
Version:        3.6.2
Release:        15%{?dist}
Epoch:          0
License:        ASL 2.0 and BSD
URL:            http://lucene.apache.org/
Source0:        https://archive.apache.org/dist/lucene/java/%{version}/lucene-%{version}-src.tgz
Source1:        lucene-%{version}-core-OSGi-MANIFEST.MF
Source2:        lucene-%{version}-analysis-OSGi-MANIFEST.MF

# DictionaryBasedBreakIterator was moved into the base RuleBasedBreakIterator
# in icu4j. v49 => v50
Patch0:         lucene_contrib_icu4j_v50.patch
# Add hamcrest-core in classpath
# Disable doclint in javadoc task
Patch1:         lucene-3.6.2-hamcrest-core.patch
# javascript not allowed in javadoc
Patch2:         lucene-3.6.2-javascript.patch
# Fix build errors in test-framework
Patch3:         test-framework.patch
#svn export http://svn.apache.org/repos/asf/lucene/dev/tags/lucene_solr_3_6_2/dev-tools@r1450168
#tar caf dev-tools.tar.xz dev-tools/
Source4:        dev-tools.tar.xz

BuildRequires:  ant
BuildRequires:  ant-junit
BuildRequires:  apache-commons-codec
BuildRequires:  apache-commons-compress
BuildRequires:  apache-commons-digester
BuildRequires:  apache-ivy
BuildRequires:  apache-parent
BuildRequires:  hamcrest-core
BuildRequires:  icu4j
BuildRequires:  ivy-local
BuildRequires:  javacc
BuildRequires:  java-javadoc
BuildRequires:  jtidy
BuildRequires:  junit
BuildRequires:  lucene3
BuildRequires:  regexp
BuildRequires:  xerces-j2

# for tests
BuildRequires:  subversion

BuildArch:      noarch

%description
Apache Lucene is a high-performance, full-featured text search
engine library written entirely in Java. It is a technology suitable
for nearly any application that requires full-text search, especially
cross-platform.

%package contrib
Summary:        Lucene contributed extensions
Requires:       %{name} = %{epoch}:%{version}-%{release}

%description contrib
%{summary}.

%package javadoc
Summary:        Javadoc for Lucene

%description javadoc
%{summary}.

%prep
%setup -q -n lucene-%{version}
# remove all binary libs
find . -name "*.jar" -delete

tar xfs %{SOURCE4}
pushd dev-tools
find . -name "pom.xml.template" -exec sed -i "s/@version@/%{version}/g" '{}' \;
popd

iconv --from=ISO-8859-1 --to=UTF-8 CHANGES.txt > CHANGES.txt.new

# prepare pom files (replace @version@ with real version)
find . -name '*pom.xml.template' -exec \
              sed -i "s:@version@:%{version}:g" '{}' \;

# must specify exact version for compat package deps
sed -i -e "s|3.5.0|3.6.2|g" backwards/ivy.xml

%patch0 -p2
%patch1 -p1
%patch2 -p1
%patch3 -p0

%build
mkdir -p docs
mkdir -p lib
export OPT_JAR_LIST="ant/ant-junit junit hamcrest/core"

export CLASSPATH=$(build-classpath jtidy regexp commons-codec commons-digester commons-compress icu4j ivy xmvn)
ant -Divy.mode=local -Dbuild.sysclasspath=first \
  -Djavacc.home=%{_bindir}/javacc \
  -Djavacc.jar=%{_javadir}/javacc.jar \
  -Djavacc.jar.dir=%{_javadir} \
  -Djavadoc.link=file://%{_javadocdir}/java \
  -Dversion=%{version} \
  -Dfailonjavadocwarning=false \
  -Dmaven-tasks.uptodate=true \
  -Djavac.source=1.6 \
  -Djavac.target=1.6 \
  -Djavac.source.backwards=1.6 \
  -Djavac.target.backwards=1.6 \
  jar-lucene-core jar-test-framework docs javadocs build-contrib

# add missing OSGi metadata to manifests
mkdir META-INF
unzip -o build/core/lucene-core-%{version}.jar META-INF/MANIFEST.MF
cp %{SOURCE1} META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip build/core/lucene-core-%{version}.jar META-INF/MANIFEST.MF

unzip -o build/contrib/analyzers/common/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF
cp %{SOURCE2} META-INF/MANIFEST.MF
sed -i '/^\r$/d' META-INF/MANIFEST.MF
zip build/contrib/analyzers/common/lucene-analyzers-%{version}.jar META-INF/MANIFEST.MF

mv build/contrib/analyzers/common build/contrib/analyzers/analyzers
mv dev-tools/maven/lucene/contrib/analyzers/common dev-tools/maven/lucene/contrib/analyzers/analyzers

# Core
sed -i -e '/relativePath/d' dev-tools/maven/pom.xml.template
%mvn_artifact dev-tools/maven/pom.xml.template
%mvn_artifact dev-tools/maven/lucene/pom.xml.template
%mvn_artifact dev-tools/maven/lucene/core/pom.xml.template build/core/lucene-core-%{version}.jar

# Contrib
%mvn_artifact dev-tools/maven/lucene/contrib/pom.xml.template
%mvn_package :lucene-contrib-aggregator contrib
for c in benchmark demo facet grouping highlighter icu instantiated join \
         memory misc pruning queries queryparser remote spatial spellchecker xml-query-parser ; do
  %mvn_artifact dev-tools/maven/lucene/contrib/$c/pom.xml.template build/contrib/$c/lucene-${c}-%{version}.jar
  %mvn_package :lucene-${c} contrib
done
for c in analyzers kuromoji phonetic smartcn stempel ; do
  %mvn_artifact dev-tools/maven/lucene/contrib/analyzers/$c/pom.xml.template build/contrib/analyzers/$c/lucene-${c}-%{version}.jar
  %mvn_package :lucene-${c} contrib
done

# Compat versions
%mvn_compat_version : 3 3.6.2

%install
%mvn_install -J build/docs/api

%files -f .mfiles
%doc CHANGES.txt README.txt
%license LICENSE.txt NOTICE.txt

%files javadoc -f .mfiles-javadoc
%license LICENSE.txt NOTICE.txt

%files contrib -f .mfiles-contrib
%doc contrib/CHANGES.txt
%license LICENSE.txt NOTICE.txt

%changelog
* Sun Dec 09 2018 Mat Booth <mat.booth@redhat.com> - 0:3.6.2-15
- Fix failure to build from source
- Use ivy-local correctly and switch away from obsolete maven macros

* Fri Jul 13 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-14
- Rebuilt for https://fedoraproject.org/wiki/Fedora_29_Mass_Rebuild

* Thu Feb 08 2018 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-13
- Rebuilt for https://fedoraproject.org/wiki/Fedora_28_Mass_Rebuild

* Mon Oct 09 2017 Troy Dawson <tdawson@redhat.com> - 0:3.6.2-12
- Fix zip -u in spec file causes race condition (#1495231)
- Cleanup spec file conditionals

* Fri Sep 22 2017 Mat Booth <mat.booth@redhat.com> - 0:3.6.2-11
- Add missing BRs to fix FTBFS

* Wed Jul 26 2017 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-10
- Rebuilt for https://fedoraproject.org/wiki/Fedora_27_Mass_Rebuild

* Wed Feb 08 2017 gil cattaneo <puntogil@libero.it> 0:3.6.2-9
- fix FTBFS

* Thu Feb 04 2016 Fedora Release Engineering <releng@fedoraproject.org> - 0:3.6.2-8
- Rebuilt for https://fedoraproject.org/wiki/Fedora_24_Mass_Rebuild

* Sat Aug 15 2015 gil cattaneo <puntogil@libero.it> 0:3.6.2-7
- fix FTBFS rhbz#1239659
- fix BR list
- introduce license macro
- fix some rpmlint problem

* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.6.2-6
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Fri Jun 13 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-5
- Support for new xmvn

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0:3.6.2-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed May 28 2014 Mikolaj Izdebski <mizdebsk@redhat.com> - 0:3.6.2-3
- Rebuild to regenerate Maven auto-requires

* Wed Apr 16 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-2
- Added other modules
- Fixed timestamps
- Updated license field

* Mon Apr 14 2014 Marek Goldmann <mgoldman@redhat.com> - 0:3.6.2-1
- Repackaged as a compat package

